@@ -1,7 +1,7 @@
 /*
 This file is part of Choqok, the KDE micro-blogging client
 
-Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -33,7 +33,6 @@ along with this program; if not, see http://www.gnu.org/licenses/
 #include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kmessagebox.h>
-#include <solid/networking.h>
 #include "mainwindow.h"
 #include <pluginmanager.h>
 #include "choqokbehaviorsettings.h"
@@ -41,7 +40,7 @@ along with this program; if not, see http://www.gnu.org/licenses/
 #include <dbushandler.h>
 
 ChoqokApplication::ChoqokApplication()
-: KUniqueApplication( true, true ), m_isShuttingDown(false)
+: Choqok::Application()
 {
     kDebug();
     setQuitOnLastWindowClosed( false );
@@ -49,9 +48,6 @@ ChoqokApplication::ChoqokApplication()
     Choqok::ChoqokDbus();
     
     m_mainWindow = new MainWindow;
-//     if ( Choqok::BehaviorSettings::showMainWinOnStart() ) {
-//         m_mainWindow->show();
-//     }
 
     Choqok::UI::Global::setMainWindow( m_mainWindow );
 
@@ -75,7 +71,7 @@ void ChoqokApplication::quitChoqok()
 {
     kDebug() ;
 
-    m_isShuttingDown = true;
+    setShuttingDown(true);
 
     if ( m_mainWindow )
     {
@@ -88,7 +84,7 @@ void ChoqokApplication::quitChoqok()
 
 void ChoqokApplication::commitData( QSessionManager &sm )
 {
-    m_isShuttingDown = true;
+    setShuttingDown(true);
     KUniqueApplication::commitData( sm );
 }
 
