@@ -1,7 +1,7 @@
 /*
     This file is part of Choqok, the KDE micro-blogging client
 
-    Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+    Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -53,11 +53,29 @@
 #include <kstandarddirs.h>
 #include <KSplashScreen>
 #include <KMenu>
-#include <uploadmediadialog.h>
+#include "uploadmediadialog.h"
 #include <knotifyconfigwidget.h>
+#include <KMenuBar>
+#include <KPushButton>
+#include <choqoktools.h>
+
+const char* mainButtonStyleSheet = "QPushButton{\
+background-color: qlineargradient(spread:reflect, x1:0.449382, y1:0, x2:0.448, y2:1, stop:0.15 rgba(255, 255, 255, 100), stop:1 rgba(61, 158, 0, 255));\
+    border: none;\
+    border-radius: 4px;\
+    width: 70px;\
+    height: 20px;\
+    }\
+    QPushButton:hover{\
+        border: 2px solid rgba(170,170,255,180);\
+    }\
+    QPushButton:pressed{\
+    background-color: qlineargradient(spread:reflect, x1:0.449382, y1:0, x2:0.448, y2:1, stop:0.3 rgba(255, 255, 255, 100), stop:1 rgba(61, 158, 0, 255));\
+    }";
 
 MainWindow::MainWindow()
-    : Choqok::UI::MainWindow(), quickWidget(0), s_settingsDialog(0), m_splash(0), microblogCounter(0)
+    : Choqok::UI::MainWindow(), quickWidget(0), s_settingsDialog(0), m_splash(0),
+    choqokMainButton(0), microblogCounter(0)
 {
     kDebug();
     setAttribute ( Qt::WA_DeleteOnClose, false );
@@ -65,9 +83,6 @@ MainWindow::MainWindow()
 
     timelineTimer = new QTimer( this );
     setWindowTitle( i18n("Choqok") );
-    mainWidget = new KTabWidget( this );
-    mainWidget->setDocumentMode(true);
-    mainWidget->setMovable(true);
     connect( mainWidget, SIGNAL(currentChanged(int)), SLOT(slotCurrentBlogChanged(int)) );
     setCentralWidget( mainWidget );
 
@@ -104,6 +119,7 @@ MainWindow::MainWindow()
     if(pos.x() != -1 && pos.y() != -1) {
         move(pos);
     }
+    actionCollection()->action("choqok_hide_menubar")->setChecked(menuBar()->isHidden());
 }
 
 MainWindow::~MainWindow()
@@ -140,6 +156,7 @@ void MainWindow::loadAllAccounts()
         delete m_splash;
         m_splash = 0;
     }
+    ChoqokApplication::setStartingUp(false);
     createQuickPostDialog();
 }
 
@@ -182,18 +199,15 @@ void MainWindow::nextTab(int delta,Qt::Orientation orientation)
 
 void MainWindow::setupActions()
 {
-    KAction *actQuit = KStandardAction::quit( this, SLOT( slotQuit() ), actionCollection() );
-    KAction *prefs = KStandardAction::preferences( this, SLOT( slotConfigChoqok() ), actionCollection() );
-//     KStandardAction::configureNotifications ( this, SLOT ( slotConfNotifications() ), actionCollection() );
+    actQuit = KStandardAction::quit( this, SLOT( slotQuit() ), actionCollection() );
+    prefs = KStandardAction::preferences( this, SLOT( slotConfigChoqok() ), actionCollection() );
 
     KAction *actUpdate = new KAction( KIcon( "view-refresh" ), i18n( "Update Timelines" ), this );
     actionCollection()->addAction( QLatin1String( "update_timeline" ), actUpdate );
     actUpdate->setShortcut( Qt::Key_F5 );
     KShortcut updateGlobalShortcut( Qt::CTRL | Qt::META | Qt::Key_F5 );
-//     updateGlobalShortcut.setAlternate ( Qt::MetaModifier | Qt::Key_F5 );
     actUpdate->setGlobalShortcut( updateGlobalShortcut );
     connect( actUpdate, SIGNAL( triggered( bool ) ), this, SIGNAL( updateTimelines() ) );
-//     connect( actUpdate, SIGNAL( triggered( bool ) ), this, SIGNAL( updateSearchResults() ) );
 
     KAction *newTwit = new KAction( KIcon( "document-new" ), i18n( "Quick Post" ), this );
     actionCollection()->addAction( QLatin1String( "choqok_new_post" ), newTwit );
@@ -210,7 +224,7 @@ void MainWindow::setupActions()
     showMain = new KAction( this );
     actionCollection()->addAction( QLatin1String( "toggle_mainwin" ), showMain );
     KShortcut toggleMainGlobalShortcut( Qt::CTRL | Qt::META | Qt::Key_C );
-    showMain->setGlobalShortcut( toggleMainGlobalShortcut/*, KAction::DefaultShortcut, KAction::NoAutoloading*/ );
+    showMain->setGlobalShortcut( toggleMainGlobalShortcut );
     if(this->isVisible())
         showMain->setText( i18n( "Minimize" ) );
     else
@@ -233,6 +247,13 @@ void MainWindow::setupActions()
     enableNotify->setShortcut( KShortcut( Qt::CTRL | Qt::Key_N ) );
     connect( enableNotify, SIGNAL( toggled( bool ) ), this, SLOT( setNotificationsEnabled( bool ) ) );
 
+    KAction* hideMenuBar = new KAction( i18n("Hide Menubar"), this );
+    hideMenuBar->setCheckable(true);
+    actionCollection()->addAction( QLatin1String( "choqok_hide_menubar" ), hideMenuBar );
+    hideMenuBar->setShortcut( KShortcut(Qt::ControlModifier | Qt::Key_M) );
+    connect( hideMenuBar, SIGNAL(toggled(bool)), menuBar(), SLOT(setHidden(bool)) );
+    connect( hideMenuBar, SIGNAL(toggled(bool)), this, SLOT(slotShowSpecialMenu(bool)) );
+
     KAction *clearAvatarCache = new KAction(KIcon("edit-clear"), i18n( "Clear Avatar Cache" ), this );
     actionCollection()->addAction( QLatin1String( "choqok_clear_avatar_cache" ), clearAvatarCache );
     QString tip = i18n( "You have to restart Choqok to load avatars again" );
@@ -245,6 +266,10 @@ void MainWindow::setupActions()
     actionCollection()->addAction( QLatin1String( "choqok_upload_medium" ), uploadMedium );
     connect( uploadMedium, SIGNAL( triggered(bool)), this, SLOT(slotUploadMedium()) );
 
+    KAction *donate = new KAction( KIcon("help-donate"), i18n("Donate"), this );
+    actionCollection()->addAction( QLatin1String( "choqok_donate" ), donate);
+    connect( donate, SIGNAL(triggered(bool)), this, SLOT(slotDonate()));
+
     ///SysTray Actions:
     sysIcon->contextMenu()->addAction( newTwit );
 //     sysIcon->contextMenu()->addAction( uploadMedium );
@@ -330,12 +355,14 @@ void MainWindow::slotAppearanceConfigChanged()
                                           Choqok::AppearanceSettings::readForeColor() ,
                                           Choqok::AppearanceSettings::readBackColor() ,
                                          Choqok::AppearanceSettings::ownForeColor() ,
-                                         Choqok::AppearanceSettings::ownBackColor());
+                                         Choqok::AppearanceSettings::ownBackColor(),
+                                         Choqok::AppearanceSettings::font() );
     } else {
         QPalette p = window()->palette();
         Choqok::UI::PostWidget::setStyle( p.color(QPalette::WindowText) , p.color(QPalette::Window).lighter() ,
                                           p.color(QPalette::WindowText) , p.color(QPalette::Window) ,
-                                         p.color(QPalette::WindowText) , p.color(QPalette::Window));
+                                          p.color(QPalette::WindowText) , p.color(QPalette::Window),
+                                          font() );
     }
     int count = mainWidget->count();
     for ( int i = 0; i < count; ++i ) {
@@ -554,8 +581,10 @@ void MainWindow::slotMarkAllAsRead()
 void MainWindow::slotCurrentBlogChanged(int)
 {
     Choqok::UI::MicroBlogWidget *wd = qobject_cast<Choqok::UI::MicroBlogWidget *>(mainWidget->currentWidget());
-    if( wd )
+    if( wd ) {
         wd->setFocus();
+        emit currentMicroBlogWidgetChanged(wd);
+    }
 }
 
 void MainWindow::oneMicroblogLoaded()
@@ -583,4 +612,37 @@ void MainWindow::slotUploadMedium()
     dlg->show();
 }
 
+void MainWindow::slotShowSpecialMenu(bool show)
+{
+    if(show) {
+        if(!choqokMainButton) {
+            choqokMainButton = new KPushButton(KIcon("choqok"), QString(), mainWidget);
+            KMenu* menu = new KMenu(i18n("Choqok"), choqokMainButton);
+            menu->addAction(actionCollection()->action("choqok_new_post"));
+            menu->addAction(actionCollection()->action("update_timeline"));
+            menu->addAction(actionCollection()->action("choqok_mark_as_read"));
+            menu->addAction(actionCollection()->action("choqok_upload_medium"));
+            menu->addSeparator();
+            menu->addAction(actionCollection()->action("choqok_enable_updates"));
+            menu->addAction(actionCollection()->action("choqok_hide_menubar"));
+            menu->addAction(prefs);
+            menu->addSeparator();
+            menu->addAction(actionCollection()->action("choqok_donate"));
+            menu->addSeparator();
+            menu->addAction(showMain);
+            menu->addAction(actQuit);
+            choqokMainButton->setMenu(menu);
+        }
+        mainWidget->setCornerWidget(choqokMainButton/*, Qt::TopLeftCorner*/);
+        choqokMainButton->show();
+    } else {
+        mainWidget->setCornerWidget(0/*, Qt::TopLeftCorner*/);
+    }
+}
+
+void MainWindow::slotDonate()
+{
+    Choqok::openUrl(QUrl("http://choqok.gnufolks.org/about/contribute/"));
+}
+
 #include "mainwindow.moc"
