@@ -1,7 +1,7 @@
 /*
     This file is part of Choqok, the KDE micro-blogging client
 
-    Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+    Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -28,6 +28,7 @@
 #include "account.h"
 #include "choqokmainwindow.h"
 
+class KPushButton;
 class KAction;
 class KSplashScreen;
 namespace Choqok
@@ -100,7 +101,9 @@ private slots:
 
     //Using this for splash screen
     void oneMicroblogLoaded();
-    
+    void slotShowSpecialMenu(bool show);
+    void slotDonate();
+
 Q_SIGNALS:
     void quickPostCreated();
 
@@ -118,6 +121,10 @@ private:
     KSettings::Dialog *s_settingsDialog;
     KSplashScreen *m_splash;
     KAction *showMain;
+    KAction *actQuit;
+    KAction *prefs;
+    KAction *aboutChoqok;
+    KPushButton *choqokMainButton;
 
     int microblogCounter;
 };
