@@ -1,7 +1,7 @@
 /*
     This file is part of Choqok, the KDE micro-blogging client
 
-    Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+    Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -48,23 +48,15 @@ public slots:
     void updateUnreadCount( int changeOfUnreadPosts );
     void resetUnreadCount();
 
-signals:
-//     void wheelEvent(const QWheelEvent&);
-
 protected slots:
     void slotRestoreIcon();
 
-protected:
-//     virtual bool event(QEvent* event);
-
 private:
+    QString currentIconName();
     int unread;
 
-    QPixmap m_defaultIcon;
-    QIcon prevIcon;
-    bool isIconChanged;
-    bool isBaseIconChanged;
     Choqok::UI::MainWindow * _mainwin;
+    bool isOffline;
 };
 
 #endif
