@@ -1,7 +1,7 @@
 /*
     This file is part of Choqok, the KDE micro-blogging client
 
-    Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+    Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -91,6 +91,7 @@ TwitterApiAccount::TwitterApiAccount(TwitterApiMicroBlog* parent, const QString
 
 TwitterApiAccount::~TwitterApiAccount()
 {
+    d->qoauth->deleteLater();
     delete d;
 }
 
@@ -276,7 +277,7 @@ void TwitterApiAccount::initQOAuthInterface()
 {
     kDebug();
     if(!d->qoauth)
-        d->qoauth = new QOAuth::Interface(new KIO::AccessManager(this), this);//TODO KDE 4.5 Change to use new class.
+        d->qoauth = new QOAuth::Interface(new KIO::AccessManager(this), this);
     d->qoauth->setConsumerKey(d->oauthConsumerKey);
     d->qoauth->setConsumerSecret(d->oauthConsumerSecret);
     d->qoauth->setRequestTimeout(20000);
