@@ -219,6 +219,7 @@ QList< Choqok::Post* > TwitterApiMicroBlog::loadTimeline( Choqok::Account *accou
             st->isRead = grp.readEntry("isRead", true);
             st->repeatedFromUsername = grp.readEntry("repeatedFrom", QString());
             st->repeatedPostId = grp.readEntry("repeatedPostId", QString());
+            st->conversationId = grp.readEntry("conversationId", QString());
 
             list.append( st );
         }
@@ -231,46 +232,47 @@ void TwitterApiMicroBlog::saveTimeline(Choqok::Account *account,
                                        const QString& timelineName,
                                        const QList< Choqok::UI::PostWidget* > &timeline)
 {
-    if(timelineName.compare("Favorite") == 0)
-        return;//NOTE Won't cache favorites, and this is for compatibility with older versions!
-    kDebug();
-    QString fileName = Choqok::AccountManager::generatePostBackupFileName(account->alias(), timelineName);
-    KConfig postsBackup( "choqok/" + fileName, KConfig::NoGlobals, "data" );
+    if(timelineName.compare("Favorite") != 0) {
+        kDebug();
+        QString fileName = Choqok::AccountManager::generatePostBackupFileName(account->alias(), timelineName);
+        KConfig postsBackup( "choqok/" + fileName, KConfig::NoGlobals, "data" );
 
-    ///Clear previous data:
-    QStringList prevList = postsBackup.groupList();
-    int c = prevList.count();
-    if ( c > 0 ) {
-        for ( int i = 0; i < c; ++i ) {
-            postsBackup.deleteGroup( prevList[i] );
+        ///Clear previous data:
+        QStringList prevList = postsBackup.groupList();
+        int c = prevList.count();
+        if ( c > 0 ) {
+            for ( int i = 0; i < c; ++i ) {
+                postsBackup.deleteGroup( prevList[i] );
+            }
         }
+        QList< Choqok::UI::PostWidget *>::const_iterator it, endIt = timeline.constEnd();
+        for ( it = timeline.constBegin(); it != endIt; ++it ) {
+            const Choqok::Post *post = &((*it)->currentPost());
+            KConfigGroup grp( &postsBackup, post->creationDateTime.toString() );
+            grp.writeEntry( "creationDateTime", post->creationDateTime );
+            grp.writeEntry( "postId", post->postId.toString() );
+            grp.writeEntry( "text", post->content );
+            grp.writeEntry( "source", post->source );
+            grp.writeEntry( "inReplyToPostId", post->replyToPostId.toString() );
+            grp.writeEntry( "inReplyToUserId", post->replyToUserId.toString() );
+            grp.writeEntry( "favorited", post->isFavorited );
+            grp.writeEntry( "inReplyToUserName", post->replyToUserName );
+            grp.writeEntry( "authorId", post->author.userId.toString() );
+            grp.writeEntry( "authorUserName", post->author.userName );
+            grp.writeEntry( "authorRealName", post->author.realName );
+            grp.writeEntry( "authorProfileImageUrl", post->author.profileImageUrl );
+            grp.writeEntry( "authorDescription" , post->author.description );
+            grp.writeEntry( "isPrivate" , post->isPrivate );
+            grp.writeEntry( "authorLocation" , post->author.location );
+            grp.writeEntry( "isProtected" , post->author.isProtected );
+            grp.writeEntry( "authorUrl" , post->author.homePageUrl );
+            grp.writeEntry( "isRead" , post->isRead );
+            grp.writeEntry( "repeatedFrom", post->repeatedFromUsername);
+            grp.writeEntry( "repeatedPostId", post->repeatedPostId.toString());
+            grp.writeEntry( "conversationId", post->conversationId.toString() );
+        }
+        postsBackup.sync();
     }
-    QList< Choqok::UI::PostWidget *>::const_iterator it, endIt = timeline.constEnd();
-    for ( it = timeline.constBegin(); it != endIt; ++it ) {
-        const Choqok::Post *post = &((*it)->currentPost());
-        KConfigGroup grp( &postsBackup, post->creationDateTime.toString() );
-        grp.writeEntry( "creationDateTime", post->creationDateTime );
-        grp.writeEntry( "postId", post->postId.toString() );
-        grp.writeEntry( "text", post->content );
-        grp.writeEntry( "source", post->source );
-        grp.writeEntry( "inReplyToPostId", post->replyToPostId.toString() );
-        grp.writeEntry( "inReplyToUserId", post->replyToUserId.toString() );
-        grp.writeEntry( "favorited", post->isFavorited );
-        grp.writeEntry( "inReplyToUserName", post->replyToUserName );
-        grp.writeEntry( "authorId", post->author.userId.toString() );
-        grp.writeEntry( "authorUserName", post->author.userName );
-        grp.writeEntry( "authorRealName", post->author.realName );
-        grp.writeEntry( "authorProfileImageUrl", post->author.profileImageUrl );
-        grp.writeEntry( "authorDescription" , post->author.description );
-        grp.writeEntry( "isPrivate" , post->isPrivate );
-        grp.writeEntry( "authorLocation" , post->author.location );
-        grp.writeEntry( "isProtected" , post->author.isProtected );
-        grp.writeEntry( "authorUrl" , post->author.homePageUrl );
-        grp.writeEntry( "isRead" , post->isRead );
-        grp.writeEntry( "repeatedFrom", post->repeatedFromUsername);
-        grp.writeEntry( "repeatedPostId", post->repeatedPostId.toString());
-    }
-    postsBackup.sync();
     if(Choqok::Application::isShuttingDown()) {
         --d->countOfTimelinesToSave;
         if(d->countOfTimelinesToSave < 1)
@@ -681,14 +683,18 @@ void TwitterApiMicroBlog::requestFriendsScreenName(TwitterApiAccount* theAccount
     TwitterApiAccount* account = qobject_cast<TwitterApiAccount*>(theAccount);
     KUrl url = account->apiUrl();
     url.addPath( QString("/statuses/friends.xml") );
+    KUrl tmpUrl(url);
     url.addQueryItem( "cursor", d->friendsCursor );
+    QOAuth::ParamMap params;
+    params.insert("cursor", d->friendsCursor.toLatin1());
 
     KIO::StoredTransferJob *job = KIO::storedGet( url, KIO::Reload, KIO::HideProgressInfo ) ;
     if ( !job ) {
         kDebug() << "Cannot create an http GET request!";
         return;
     }
-    job->addMetaData("customHTTPHeader", "Authorization: " + authorizationHeader(account, url, QOAuth::GET));
+    job->addMetaData("customHTTPHeader", "Authorization: " + authorizationHeader(account, tmpUrl,
+                                                                                 QOAuth::GET, params));
     mJobsAccount[job] = theAccount;
     connect( job, SIGNAL( result( KJob* ) ), this, SLOT( slotRequestFriendsScreenName(KJob*) ) );
     job->start();
@@ -895,6 +901,8 @@ Choqok::Post* TwitterApiMicroBlog::readPostFromDomNode(Choqok::Account* theAccou
             post->source = elm.text();
         else if ( elm.tagName() == "favorited" )
             post->isFavorited = ( elm.text() == "true" ) ? true : false;
+        else if ( elm.tagName() == "statusnet:conversation_id" )
+            post->conversationId = elm.text();
         else if ( elm.tagName() == "user" ) {
             QDomNode node3 = node.firstChild();
             while ( !node3.isNull() ) {
@@ -1151,11 +1159,12 @@ void TwitterApiMicroBlog::setRepeatedOfInfo(Choqok::Post* post, Choqok::Post* re
 QDateTime TwitterApiMicroBlog::dateFromString ( const QString &date )
 {
     char s[10];
-    int year, day, hours, minutes, seconds;
-    sscanf( qPrintable ( date ), "%*s %s %d %d:%d:%d %*s %d", s, &day, &hours, &minutes, &seconds, &year );
+    int year, day, hours, minutes, seconds, tz;
+    sscanf( qPrintable ( date ), "%*s %s %d %d:%d:%d %d %d", s, &day, &hours, &minutes, &seconds, &tz, &year );
     int month = d->monthes[s];
     QDateTime recognized ( QDate ( year, month, day ), QTime ( hours, minutes, seconds ) );
-    recognized.setTimeSpec( Qt::UTC );
+    if(tz == 0)//tz is the timezone, in Twitter it's always UTC(0) in Identica it's local +/-NUMBER
+        recognized.setTimeSpec( Qt::UTC );
     return recognized.toLocalTime();
 }
 
