@@ -137,10 +137,14 @@ QString TwitterApiPostWidget::generateSign()
             QString link = currentAccount()->microblog()->postUrl( currentAccount(), currentPost().replyToUserName,
                                                                    currentPost().replyToPostId );
             QString showConMsg = i18n("Show Conversation");
-            QString threadlink = "thread://" + currentPost().postId;
+            QString threadlink;
+            if( currentPost().conversationId.isEmpty() )
+                threadlink = "thread://" + currentPost().postId;
+            else
+                threadlink = "conversation://" + currentPost().conversationId;
             sign += " - " +
-            i18n("<a href='replyto://%1'>in reply to</a>&nbsp;<a href=\"%2\" title=\"%2\">%3</a>",
-                currentPost().replyToPostId, link, webIconText) + ' ';
+            i18n("<a href='replyto://%1'>in reply to</a> @<a href='user://%4'>%4</a>&nbsp;<a href=\"%2\" title=\"%2\">%3</a>",
+                 currentPost().replyToPostId, link, webIconText, currentPost().replyToUserName) + ' ';
             sign += "<a title=\""+ showConMsg +"\" href=\"" + threadlink + "\"><img src=\"icon://thread\" /></a>";
         }
     }
@@ -159,35 +163,36 @@ QString TwitterApiPostWidget::generateSign()
 
 void TwitterApiPostWidget::slotReply()
 {
-    setReadInternal();
+    setReadWithSignal();
     if(currentPost().isPrivate){
         TwitterApiAccount *account= qobject_cast<TwitterApiAccount*>( currentAccount() );
         d->mBlog->showDirectMessageDialog( account, currentPost().author.userName );
     } else {
         QString replyto = QString("@%1").arg(currentPost().author.userName);
         QString postId = currentPost().postId;
+        QString username = currentPost().author.userName;
         if( !currentPost().repeatedFromUsername.isEmpty() ){
             replyto.prepend(QString("@%1 ").arg(currentPost().repeatedFromUsername));
             postId = currentPost().repeatedPostId;
         }
-        emit reply( replyto, postId );
+        emit reply( replyto, postId,  username);
     }
 }
 
 void TwitterApiPostWidget::slotWriteTo()
 {
-    emit reply( QString("@%1").arg(currentPost().author.userName), QString() );
+    emit reply( QString("@%1").arg(currentPost().author.userName), QString(), currentPost().author.userName );
 }
 
 void TwitterApiPostWidget::slotReplyToAll()
 {
     QString txt = QString("@%1").arg(currentPost().author.userName);
-    emit reply(txt, currentPost().postId);
+    emit reply(txt, currentPost().postId, currentPost().author.userName);
 }
 
 void TwitterApiPostWidget::setFavorite()
 {
-    setReadInternal();
+    setReadWithSignal();
     TwitterApiMicroBlog *mic = d->mBlog;
     if(currentPost().isFavorited){
         connect(mic, SIGNAL(favoriteRemoved(Choqok::Account*,QString)),
@@ -245,8 +250,8 @@ void TwitterApiPostWidget::checkAnchor(const QUrl & url)
     } else if (scheme == "thread") {
         TwitterApiShowThread *wd = new TwitterApiShowThread(currentAccount(), currentPost(), NULL);
         wd->resize(this->width(), wd->height());
-        connect(wd, SIGNAL(forwardReply(QString,QString)),
-                this, SIGNAL(reply(QString,QString)));
+        connect(wd, SIGNAL(forwardReply(QString,QString,QString)),
+                this, SIGNAL(reply(QString,QString,QString)));
         connect(wd, SIGNAL(forwardResendPost(QString)),
                 this, SIGNAL(resendPost(QString)));
         wd->show();
@@ -285,7 +290,7 @@ void TwitterApiPostWidget::slotBasePostFetched(Choqok::Account* theAccount, Choq
 
 void TwitterApiPostWidget::repeatPost()
 {
-    setReadInternal();
+    setReadWithSignal();
     ChoqokId postId;
     if(currentPost().repeatedPostId.isEmpty())
         postId = currentPost().postId;
