@@ -1,7 +1,7 @@
 /*
     This file is part of Choqok, the KDE micro-blogging client
 
-    Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+    Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -49,7 +49,7 @@ protected Q_SLOTS:
 
 Q_SIGNALS:
     void forwardResendPost( const QString &post );
-    void forwardReply(const QString &txt, const QString &replyToId);
+    void forwardReply(const QString &txt, const QString &replyToId, const QString &replyToUsername);
 
 protected:
     void addPostWidgetToUi(Choqok::UI::PostWidget *widget);
