@@ -1,7 +1,7 @@
 /*
     This file is part of Choqok, the KDE micro-blogging client
 
-    Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+    Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -31,7 +31,7 @@
 #include <QHash>
 #include <KEmoticons>
 #include <KEmoticonsTheme>
-#include <KPixmapCache>
+#include <KImageCache>
 #include <choqokbehaviorsettings.h>
 #include "uploader.h"
 #include "pluginmanager.h"
@@ -47,10 +47,10 @@ class MediaManager::Private
 {
 public:
     Private()
-    :emoticons(KEmoticons().theme()),cache("choqok-userimages"), uploader(0)
+    :emoticons(KEmoticons().theme()),cache("choqok-userimages", 20000000), uploader(0)
     {}
     KEmoticonsTheme emoticons;
-    KPixmapCache cache;
+    KImageCache cache;
     QHash<KJob*, QString> queue;
     QPixmap defaultImage;
     Uploader *uploader;
@@ -61,7 +61,6 @@ MediaManager::MediaManager()
 {
   KIcon icon("image-loading");
   d->defaultImage = icon.pixmap(48);
-  d->cache.setCacheLimit(20000);
 }
 
 MediaManager::~MediaManager()
@@ -93,7 +92,7 @@ QString MediaManager::parseEmoticons(const QString& text)
 QPixmap * MediaManager::fetchImage( const QString& remoteUrl, ReturnMode mode /*= Sync*/ )
 {
     QPixmap *p = new QPixmap();
-    if( d->cache.find(remoteUrl,*p) ) {
+    if( d->cache.findPixmap(remoteUrl,p) ) {
         emit imageFetched(remoteUrl, *p);
         return p;
     } else if(mode == Async) {
@@ -131,7 +130,7 @@ void MediaManager::slotImageFetched( KJob * job )
         QPixmap p;
         if( !baseJob->data().startsWith(QByteArray("<?xml version=\"")) &&
             p.loadFromData( baseJob->data() ) ) {
-            d->cache.insert( remote, p );
+            d->cache.insertPixmap( remote, p );
             emit imageFetched( remote, p );
         } else {
             kDebug()<<"Parse Error: \nBase Url:"<<baseJob->url()<<"\ndata:"<<baseJob->data();
@@ -142,7 +141,7 @@ void MediaManager::slotImageFetched( KJob * job )
 
 void MediaManager::clearImageCache()
 {
-  d->cache.discard();
+  d->cache.clear();
 }
 
 QPixmap MediaManager::convertToGrayScale(const QPixmap& pic)
@@ -205,13 +204,13 @@ QByteArray MediaManager::createMultipartFormData(const QMap< QString, QByteArray
 {
     QByteArray newLine("\r\n");
     QString formHeader( newLine + "Content-Disposition: form-data; name=\"%1\"" );
-    QByteArray header(newLine + "--AaB03x");
-    QByteArray footer(newLine + "--AaB03x--");
+    QByteArray header("--AaB03x");
+    QByteArray footer("--AaB03x--");
     QString fileHeader(newLine + "Content-Disposition: file; name=\"%1\"; filename=\"%2\"");
     QByteArray data;
 
     data.append(header);
-    
+
     if ( !mediaFiles.isEmpty() ) {
         QList< QMap< QString, QByteArray > >::const_iterator it1 = mediaFiles.constBegin();
         QList< QMap< QString, QByteArray > >::const_iterator endIt1 = mediaFiles.constEnd();
@@ -222,15 +221,17 @@ QByteArray MediaManager::createMultipartFormData(const QMap< QString, QByteArray
             data.append(newLine + it1->value("medium"));
         }
     }
-    
+
     QMap< QString, QByteArray >::const_iterator it = formdata.constBegin();
     QMap< QString, QByteArray >::const_iterator endIt = formdata.constEnd();
     for(;it!=endIt; ++it){
+        data.append(newLine);
         data.append(header);
         data.append(formHeader.arg(it.key()).toLatin1());
         data.append(newLine);
         data.append(newLine + it.value());
     }
+    data.append(newLine);
     data.append(footer);
 
     return data;
