@@ -1,7 +1,7 @@
 /*
     This file is part of Choqok, the KDE micro-blogging client
 
-    Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+    Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -32,6 +32,7 @@
 #include "postwidget.h"
 #include "microblogwidget.h"
 #include "accountmanager.h"
+#include <choqokbehaviorsettings.h>
 
 namespace Choqok
 {
@@ -42,12 +43,18 @@ public:
     QString homepage;
     uint charLimit;
     QStringList timelineTypes;
+    QTimer* saveTimelinesTimer;
 };
 
 MicroBlog::MicroBlog( const KComponentData &instance, QObject *parent )
     :Plugin(instance, parent), d(new Private)
 {
     kDebug();
+    d->saveTimelinesTimer = new QTimer(this);
+    d->saveTimelinesTimer->setInterval(BehaviorSettings::notifyInterval() * 60000);
+    connect(d->saveTimelinesTimer, SIGNAL(timeout()), SIGNAL(saveTimelines()));
+    connect(BehaviorSettings::self(), SIGNAL(configChanged()), this, SLOT(slotConfigChanged()));
+	d->saveTimelinesTimer->start();
 }
 
 MicroBlog::~MicroBlog()
@@ -136,6 +143,11 @@ bool MicroBlog::isValidTimeline( const QString &timeline )
     return d->timelineTypes.contains( timeline );
 }
 
+void MicroBlog::slotConfigChanged()
+{
+    d->saveTimelinesTimer->setInterval(BehaviorSettings::notifyInterval() * 60000);
+}
+
 /// UI Objects:
 
 Account* MicroBlog::createNewAccount(const QString& alias)
