@@ -1,7 +1,7 @@
 /*
 This file is part of Choqok, the KDE micro-blogging client
 
-Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -58,7 +58,7 @@ public:
         WId id = 0;
         if(Choqok::UI::Global::mainWindow())
             id = Choqok::UI::Global::mainWindow()->winId();
-        wallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet(), id);
+        wallet = KWallet::Wallet::openWallet(KWallet::Wallet::NetworkWallet(), id);
         if ( wallet ) {
             if ( !wallet->setFolder( "choqok" ) ) {
                 wallet->createFolder( "choqok" );
