@@ -180,7 +180,7 @@ void TextEdit::slotAboutToShowContextMenu(QMenu* menu)
         act->setMenu(d->langActions);
         menu->addAction(act);
 
-        KAction *shorten = new KAction(i18nc("Replcae URLs by a shortened URL", "Shorten URLs"), menu);
+        KAction *shorten = new KAction(i18nc("Replace URLs by a shortened URL", "Shorten URLs"), menu);
         connect(shorten, SIGNAL(triggered(bool)), SLOT(shortenUrls()));
         menu->addAction(shorten);
     }
