@@ -1,7 +1,7 @@
 /*
 This file is part of Choqok, the KDE micro-blogging client
 
-Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -48,7 +48,8 @@ public:
     TextEdit *editor();
 
 public Q_SLOTS:
-    virtual void setText(const QString &text, const QString &replyToId = QString());
+    virtual void setText(const QString &text, const QString &replyToId = QString(),
+                         const QString& replyToUsername = QString());
     virtual void abort();
 
 protected Q_SLOTS:
@@ -70,6 +71,7 @@ protected:
 
 
     QString replyToId;
+    QString replyToUsername;
     QPointer<KPushButton> btnAbort;
 
 private:
