@@ -1,7 +1,7 @@
 /*
 This file is part of Choqok, the KDE micro-blogging client
 
-Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -29,6 +29,7 @@ along with this program; if not, see http://www.gnu.org/licenses/
 #include <choqoktypes.h>
 #include "choqok_export.h"
 #include "microblog.h"
+#include "choqoktabbar.h"
 
 class QLabel;
 class KTabWidget;
@@ -138,7 +139,7 @@ protected:
     void setComposerWidget(ComposerWidget* widget);
     ComposerWidget *composer();
     QMap<QString, TimelineWidget*> &timelines();
-    KTabWidget *timelinesTabWidget();
+    Choqok::UI::ChoqokTabBar *timelinesTabWidget();
     QLabel *latestUpdate();
 
 private:
