@@ -1,7 +1,7 @@
 /*
 This file is part of Choqok, the KDE micro-blogging client
 
-Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -82,28 +82,29 @@ const QString PostWidget::otherText ( "<table height=\"100%\" width=\"100%\"><tr
 width=\"48\">%1</td><td width=\"5\"><!-- EMPTY HAHA --></td><td dir=\"%4\"><p>%2</p></td></tr><tr><td><!-- EMPTY HAHA --></td><td style=\"font-size:small;\" dir=\"ltr\" align=\"right\" width=\"100%\" valign=\"bottom\">%3</td></tr></table>");
 
 const QString PostWidget::baseStyle ("KTextBrowser {border: 1px solid rgb(150,150,150);\
-border-radius:5px;}  KTextBrowser {color:%1; background-color:%2}\
+border-radius:5px; color:%1; background-color:%2; %3}\
 KPushButton{border:0px}");
 
 const QString protocols = "((https?|ftps?)://)";
 const QString subdomains = "(([a-z0-9\\-_]{1,}\\.)?)";
-const QString auth = "((([a-z0-9\\-_]{1,})((:[\\S]{1,})?)@)?)";
+const QString auth = "(([a-z0-9\\-_]{1,})((:[\\S]{1,})?)@)";
 const QString domains = "(([a-z0-9\\-\\x0080-\\xFFFF_]){1,63}\\.)+";
 const QString port = "(:(6553[0-5]|655[0-2][0-9]|65[0-4][\\d]{2}|6[0-4][\\d]{3}|[1-5][\\d]{4}|[1-9][\\d]{0,3}))";
 const QString zone ("((a[cdefgilmnoqrstuwxz])|(b[abdefghijlmnorstvwyz])|(c[acdfghiklmnoruvxyz])|(d[ejkmoz])|(e[ceghrstu])|\
 (f[ijkmor])|(g[abdefghilmnpqrstuwy])|(h[kmnrtu])|(i[delmnoqrst])|(j[emop])|(k[eghimnprwyz])|(l[abcikrstuvy])|\
 (m[acdefghklmnopqrstuvwxyz])|(n[acefgilopruz])|(om)|(p[aefghklnrstwy])|(qa)|(r[eosuw])|(s[abcdeghijklmnortuvyz])|\
 (t[cdfghjkmnoprtvwz])|(u[agksyz])|(v[aceginu])|(w[fs])|(ye)|(z[amrw])\
-|(asia|com|info|net|org|biz|name|pro|aero|cat|coop|edu|jobs|mobi|museum|tel|travel|gov|int|mil|local)|(中国)|(公司)|(网络)|(صر)|(امارات)|(рф))");
+|(asia|com|info|net|org|biz|name|pro|aero|cat|coop|edu|jobs|mobi|museum|tel|travel|gov|int|mil|local|xxx)|(中国)|(公司)|(网络)|(صر)|(امارات)|(рф))");
 const QString ip = "(25[0-5]|[2][0-4][0-9]|[0-1]?[\\d]{1,2})(\\.(25[0-5]|[2][0-4][0-9]|[0-1]?[\\d]{1,2})){3}";
 const QString params = "(((\\/)[\\w:/\\?#\\[\\]@!\\$&\\(\\)\\*%\\+,;=\\._~\\x0080-\\xFFFF\\-\\|]{1,}|%[0-9a-f]{2})?)";
 
-const QRegExp PostWidget::mUrlRegExp("((((" + protocols + "?)" + auth +
+const QRegExp PostWidget::mUrlRegExp("(((((" + protocols + auth + "?)?)" +
                           subdomains +
-                          '(' + domains +               
+                          '(' + domains +
                           zone + "(?!(\\w))))|(" + protocols + '(' + ip + ")+))" +
                           '(' + port + "?)" + "((\\/)?)"  +
                           params + ')', Qt::CaseInsensitive);
+const QRegExp PostWidget::mEmailRegExp('^' + auth + subdomains + domains + zone);
 const QRegExp PostWidget::dirRegExp("(RT|RD)|(@([^\\s\\W]+))|(#([^\\s\\W]+))|(!([^\\s\\W]+))");
 
 QString PostWidget::readStyle;
@@ -128,7 +129,14 @@ PostWidget::PostWidget( Account* account, const Choqok::Post& post, QWidget* par
 
 void PostWidget::checkAnchor(const QUrl & url)
 {
-    Choqok::openUrl(url);
+    if(url.scheme() == "choqok"){
+        if(url.host() == "showoriginalpost"){
+            setContent( prepareStatus(currentPost().content).replace("<a href","<a style=\"text-decoration:none\" href",Qt::CaseInsensitive) );
+            updateUi();
+        }
+    } else {
+        Choqok::openUrl(url);
+    }
 }
 
 PostWidget::~PostWidget()
@@ -215,11 +223,13 @@ void PostWidget::updateUi()
                                         d->dir ));
 }
 
-void PostWidget::setStyle(const QColor& color, const QColor& back, const QColor& read, const QColor& readBack, const QColor& own, const QColor& ownBack)
+void PostWidget::setStyle(const QColor& color, const QColor& back, const QColor& read, const QColor& readBack, const QColor& own, const QColor& ownBack, const QFont& font)
 {
-    unreadStyle = baseStyle.arg( getColorString(color), getColorString(back) );
-    readStyle = baseStyle.arg( getColorString(read), getColorString(readBack) );
-    ownStyle = baseStyle.arg( getColorString(own), getColorString(ownBack) );
+    QString fntStr = "font-family:\"" + font.family() + "\"; font-size:" + QString::number(font.pointSize()) + ";";
+    fntStr += (font.bold() ? " font-weight:bold;" : QString()) + (font.italic() ? " font-style:italic;" : QString());
+    unreadStyle = baseStyle.arg( getColorString(color), getColorString(back), fntStr);
+    readStyle = baseStyle.arg( getColorString(read), getColorString(readBack), fntStr );
+    ownStyle = baseStyle.arg( getColorString(own), getColorString(ownBack), fntStr );
 }
 
 QString PostWidget::getColorString(const QColor& color)
@@ -273,7 +283,7 @@ void PostWidget::setRead(bool read/* = true*/)
     }
 }
 
-void PostWidget::setReadInternal()
+void PostWidget::setReadWithSignal()
 {
     if(!isRead()){
         setRead();
@@ -310,7 +320,7 @@ void PostWidget::closeEvent(QCloseEvent* event)
 {
     clearFocus();
     if( !isRead() )
-        setReadInternal();
+        setReadWithSignal();
     Q_EMIT aboutClosing(currentPost().postId, this);
     event->accept();
 }
@@ -318,7 +328,7 @@ void PostWidget::closeEvent(QCloseEvent* event)
 void PostWidget::mousePressEvent(QMouseEvent* ev)
 {
     if(!isRead()) {
-        setReadInternal();
+        setReadWithSignal();
     }
     QWidget::mousePressEvent(ev);
 }
@@ -372,6 +382,22 @@ QString PostWidget::prepareStatus( const QString &txt )
         pos += tmplink.length();
     }
 
+    pos = 0;
+    while(((pos = mEmailRegExp.indexIn(text, pos)) != -1)) {
+        QString link = mEmailRegExp.cap(0);
+        QString tmplink = link;
+        if ( (pos - 1 > -1 && ( text.at( pos - 1 ) != '@' &&
+            text.at( pos - 1 ) != '#' && text.at( pos - 1 ) != '!')) ||
+            pos == 0 ) {
+            tmplink.prepend("mailto:");
+            text.remove( pos, link.length() );
+            static const QString hrefTemplate("<a href='%1' title='%1'>%2</a>");
+            tmplink = hrefTemplate.arg( tmplink, link );
+            text.insert( pos, tmplink );
+            }
+            pos += tmplink.length();
+    }
+
     if(AppearanceSettings::isEmoticonsEnabled())
         text = MediaManager::self()->parseEmoticons(text);
 
@@ -431,7 +457,7 @@ void PostWidget::removeCurrentPost()
         connect( d->mCurrentAccount->microblog(),
                 SIGNAL(errorPost(Choqok::Account*, Choqok::Post*,Choqok::MicroBlog::ErrorType,QString)),
                 this, SLOT(slotPostError(Choqok::Account*, Choqok::Post*,Choqok::MicroBlog::ErrorType,QString)) );
-        setReadInternal();
+        setReadWithSignal();
         d->mCurrentAccount->microblog()->removePost(d->mCurrentAccount, &d->mCurrentPost);
     }
 }
@@ -445,7 +471,7 @@ void PostWidget::slotCurrentPostRemoved( Account* theAccount, Post* post )
 void PostWidget::slotResendPost()
 {
     QString text = generateResendText();
-    setReadInternal();
+    setReadWithSignal();
     if((BehaviorSettings::resendWithQuickPost() || currentAccount()->isReadOnly()) && Global::quickPostWidget())
         Global::quickPostWidget()->setText(text);
     else
