@@ -54,6 +54,12 @@ public:
     virtual ~PostWidget();
     const Post &currentPost() const;
     virtual void setRead(bool read = true);
+
+    /**
+     Sets post widget as read, and emits postReaded() signal
+     */
+    void setReadWithSignal();
+
     virtual bool isRead() const;
 
     Account *currentAccount();
@@ -68,9 +74,10 @@ public:
 
     @see setUiStyle()
     */
-    static void setStyle(const QColor& unreadColor, const QColor& unreadBack,
+    static void setStyle( const QColor& unreadColor, const QColor& unreadBack,
                           const QColor& readColor, const QColor& readBack,
-                          const QColor& ownColor, const QColor& ownBack);
+                          const QColor& ownColor, const QColor& ownBack,
+                          const QFont& font);
 
     /**
     @brief Set current post
@@ -138,7 +145,7 @@ Q_SIGNALS:
     /**
     Carry reply information, to reply to a post.
     */
-    void reply(const QString &txt, const QString &replyToId);
+    void reply(const QString &txt, const QString &replyToId, const QString &replyToUsername);
 
     /**
     Emitted when this widget is about to close!
@@ -202,12 +209,6 @@ protected:
     KPushButton * addButton(const QString & objName, const QString & toolTip, const KIcon & icon);
     QMap<QString, KPushButton*> &buttons();
 
-    /**
-    Sets post widget as read, and emits postReaded() signal
-    Use this from inside PostWidget class and its subclasses
-    */
-    void setReadInternal();
-
 protected:
     TextBrowser *_mainWidget;
     const QString *baseText;
@@ -216,6 +217,7 @@ protected:
     static QString unreadStyle;
     static QString ownStyle;
     static const QRegExp mUrlRegExp;
+    static const QRegExp mEmailRegExp;
     static const QString webIconText;
     static const QString ownText;
     static const QString otherText;
