@@ -62,6 +62,11 @@ public:
     */
     QString timelineInfoName();
 
+    /**
+    @brief Return Timeline name for UI
+    */
+    QString timelineIcon();
+
     /**
      @brief Add new posts to UI.
     */
@@ -105,7 +110,7 @@ public Q_SLOTS:
 
 Q_SIGNALS:
     void forwardResendPost( const QString &post );
-    void forwardReply(const QString &txt, const QString &replyToId);
+    void forwardReply(const QString &txt, const QString &replyToId, const QString &replyToUsername);
     /**
     @brief Emit to inform MicroBlogWidget about changes on count of unread posts
 
