@@ -1,7 +1,7 @@
 /*
     This file is part of Choqok, the KDE micro-blogging client
 
-    Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+    Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -147,14 +147,17 @@ void LaconicaComposerWidget::selectMediumToAttach()
         d->editorLayout->addWidget(d->mediumName, 1, 0);
         d->editorLayout->addWidget(d->btnCancel, 1, 1);
     }
-    d->mediumName->setText(fileName);
+    d->mediumName->setText(i18n("Attaching <b>%1</b>", fileName));
+    editor()->setFocus();
 }
 
 void LaconicaComposerWidget::cancelAttachMedium()
 {
     kDebug();
     delete d->mediumName;
+    d->mediumName = 0;
     delete d->btnCancel;
+    d->btnCancel = 0;
     d->mediumToAttach.clear();
 }
 
