@@ -1,7 +1,7 @@
 /*
     This file is part of Choqok, the KDE micro-blogging client
 
-    Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+    Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -40,6 +40,18 @@ public:
     TwitterAccount(TwitterMicroBlog* parent, const QString& alias);
     ~TwitterAccount();
 
+    void setApi(const QString &api);
+
+    KUrl uploadUrl() const;
+
+    QString uploadHost() const;
+    void setUploadHost(const QString &uploadHost);
+
+protected:
+    void setUploadUrl(const KUrl &url);
+    void generateUploadUrl();
+
+
 private:
     class Private;
     Private *d;
